==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/turtle/dialogs_es.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("¿Puedes verlo? Esta debe de ser esa tortuga telepática.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Si, esta es. La tortuga telepática.")


dialogId("zel-m-fotky0", "font_small", "Well, I don`t know. Judging from those photos, it could be it.")
dialogStr("Bueno, yo no sé. De acuerdo a las fotos, podría ser ésta.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("No estoy seguro... ¿Qué hay sobre esos poderes telepáticos?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("En cualquier caso tenemos que sacarla de la habitación.")


dialogId("zel-v-zmistnosti1", "font_big", "Let`s take out that turtle.")
dialogStr("Saquemos esa tortuga.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("¿Qué estás haciendo?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("¿Qué has hecho?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("¿Qué se supone que significa?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("¿Donde estás nadando?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("¿Qué quiere decir?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("¿Qué te pasó?")


dialogId("zel-m-nevim0", "font_small", "I don`t know...")
dialogStr("No lo sé...")


dialogId("zel-m-nevim1", "font_small", "I can`t realize...")
dialogStr("No me puedo dar cuenta...")


dialogId("zel-v-nevim0", "font_big", "I don`t know what`s happening to me...")
dialogStr("No sé lo que me está pasando...")


dialogId("zel-v-nevim1", "font_big", "I didn`t want to...")
dialogStr("Yo no quise...")


dialogId("zel-v-cosedeje", "font_big", "What`s happening to us?")
dialogStr("¿Qué nos está pasando?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("¿Qué puede significar eso?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("¡Esto debe de ser esa tortuga!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("¡Debe de ser esa tortuga!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Entonces no pueden haber dudas ahora - este es. ¡El que estamos buscando!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Sin duda, ¡Esta es la tortuga que estamos buscando!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("¡Esa bestia!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("¡Detente, demonio!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("¡Es suficiente!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("¿Te estás divirtiendo?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tantas formas extrañas solo pueden encontrarse en un arrecife de coral.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature`s wonders.")
dialogStr("Esos corales son maravillas de la Madre Naturaleza.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("¿Desde donde vienen tantas formas extrañas?")


dialogId("zel-m-jednoduse", "font_small", "It`s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Es fácil - los diseñadores crean problemas difíciles y dejan el dibujo a los artistas gráficos.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Nuestro objetivo en esta habitación es sacar esa tortuga.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_es.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("¿Puedes verlo? Esta debe de ser esa tortuga telepática.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Si, esta es. La tortuga telepática.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("Bueno, yo no sé. De acuerdo a las fotos, podría ser ésta.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("No estoy seguro... ¿Qué hay sobre esos poderes telepáticos?")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("En cualquier caso tenemos que sacarla de la habitación.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Saquemos esa tortuga.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("¿Qué estás haciendo?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("¿Qué has hecho?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("¿Qué se supone que significa?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("¿Donde estás nadando?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("¿Qué quiere decir?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("¿Qué te pasó?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("No lo sé...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("No me puedo dar cuenta...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("No sé lo que me está pasando...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Yo no quise...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("¿Qué nos está pasando?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("¿Qué puede significar eso?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("¡Esto debe de ser esa tortuga!")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("¡Debe de ser esa tortuga!")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Entonces no pueden haber dudas ahora - este es. ¡El que estamos buscando!")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Sin duda, ¡Esta es la tortuga que estamos buscando!")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("¡Esa bestia!")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("¡Detente, demonio!")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("¡Es suficiente!")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("¿Te estás divirtiendo?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tantas formas extrañas solo pueden encontrarse en un arrecife de coral.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Esos corales son maravillas de la Madre Naturaleza.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("¿Desde donde vienen tantas formas extrañas?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Es fácil - los diseñadores crean problemas difíciles y dejan el dibujo a los artistas gráficos.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Nuestro objetivo en esta habitación es sacar esa tortuga.")
